[Zope3-checkins] CVS: Zope3/src/zope/app/services/tests - placefulsetup.py:1.11 test_eventservice.py:1.13

R. Sean Bowman sean.bowman@acm.org
Sat, 8 Mar 2003 16:46:41 -0500


Update of /cvs-repository/Zope3/src/zope/app/services/tests
In directory cvs.zope.org:/tmp/cvs-serv32568/zope/app/services/tests

Modified Files:
	placefulsetup.py test_eventservice.py 
Log Message:
changed EventDispatch to EventPublication, modified some zcml to be more
consistent with the new service names


=== Zope3/src/zope/app/services/tests/placefulsetup.py 1.10 => 1.11 ===
--- Zope3/src/zope/app/services/tests/test_eventservice.py:1.12	Fri Mar  7 19:51:46 2003
+++ Zope3/src/zope/app/services/tests/test_eventservice.py	Sat Mar  8 16:46:09 2003
@@ -21,7 +21,7 @@
 from zope.interface import Interface
 from zope.app.services.service import ServiceManager, ServiceConfiguration
 from zope.component import getServiceManager
-from zope.app.services.servicenames import EventDispatch, EventSubscription
+from zope.app.services.servicenames import EventPublication, EventSubscription
 from zope.app.services.event import EventService
 from zope.app.traversing import getPhysicalPathString, traverse
 from zope.exceptions import NotFoundError
@@ -812,7 +812,7 @@
         default.setObject("myEventService", service)
 
         path = "%s/Packages/default/myEventService" % getPhysicalPathString(sm)
-        configuration = ServiceConfiguration(EventDispatch, path)
+        configuration = ServiceConfiguration(EventPublication, path)
         default['configure'].setObject("myEventServiceDir", configuration)
         traverse(default, 'configure/1').status = Active
 
@@ -869,7 +869,7 @@
             )
 
         sm = traverse(self.rootFolder, "folder1/++etc++Services")
-        configuration = sm.queryConfigurations(EventDispatch).active()
+        configuration = sm.queryConfigurations(EventPublication).active()
         configuration.status = Registered
         publish(self.rootFolder, ObjectAddedEvent(None, '/foo'))
         self.assertEqual(self.folder1Subscriber.notified, 1)
@@ -896,7 +896,7 @@
         configuration = sm.queryConfigurations(EventSubscription).active()
         # make sure it doesn't raise any errors
         configuration.status = Registered
-        configuration = sm.queryConfigurations(EventDispatch).active()
+        configuration = sm.queryConfigurations(EventPublication).active()
         # make sure it doesn't raise any errors
         configuration.status = Registered
--- Zope3/src/zope/app/services/tests/placefulsetup.py:1.10	Fri Mar  7 19:51:46 2003
+++ Zope3/src/zope/app/services/tests/placefulsetup.py	Sat Mar  8 16:46:09 2003
@@ -19,7 +19,7 @@
 from zope import component as CA
 from zope.component.adapter import provideAdapter
 from zope.component.view import provideView
-from zope.app.services.servicenames import HubIds, EventDispatch, EventSubscription
+from zope.app.services.servicenames import HubIds, EventPublication, EventSubscription
 from zope.publisher.interfaces.browser import IBrowserPresentation
 
 from zope.app.browser.absoluteurl import SiteAbsoluteURL, AbsoluteURL
@@ -160,7 +160,7 @@
 
     def createEventService(self, folder_path):
         """Create an event service in 'folder', and configure it for
-        EventDispatch and EventSubscription services."""
+        EventPublication and EventSubscription services."""
         folder = traverse(self.rootFolder, folder_path)
         if not folder.hasServiceManager():
             folder.setServiceManager(ServiceManager())
@@ -171,7 +171,7 @@
         default.setObject(service_name, EventService())
 
         path = "%s/%s" % (getPhysicalPathString(default), service_name)
-        configuration = ServiceConfiguration(EventDispatch, path, self.rootFolder)
+        configuration = ServiceConfiguration(EventPublication, path, self.rootFolder)
         default['configure'].setObject(
                 "%sEventsDir" % service_name, configuration)
         traverse(default, 'configure/1').status = Active
@@ -199,7 +199,7 @@
         from zope.app.services.event import EventService
         defineService(EventSubscription, ISubscriptionService)
 
         # EventDispatch service already defined by
         # zope.app.events.tests.PlacelessSetup
 
         defineService(HubIds, IObjectHub)
@@ -210,7 +210,7 @@
         default.setObject("myObjectHub", self.getObjectHub())
 
         path = "%s/Packages/default/myEventService" % getPhysicalPathString(sm)
-        configuration = ServiceConfiguration(EventDispatch, path, self.rootFolder)
+        configuration = ServiceConfiguration(EventPublication, path, self.rootFolder)
         default['configure'].setObject("myEventServiceDir", configuration)
         traverse(default, 'configure/1').status = Active
 
@@ -199,7 +199,7 @@
         defineService(EventSubscription, ISubscriptionService)
 
-        # EventDispatch service already defined by
+        # EventPublication service already defined by
         # zope.app.events.tests.PlacelessSetup
 


=== Zope3/src/zope/app/services/tests/test_eventservice.py 1.12 => 1.13 ===